==> apache-kylin-3.0.0-source-release.zip: apache-kylin-3.0.0/core-common/src/main/java/org/apache/kylin/common/SourceDialect.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kylin.common;

/**
 * Decide sql pattern according to dialect from differenct data source
 */
public enum SourceDialect {
    HIVE("hive"),

    /**
     * Support MySQL 5.7
     */
    MYSQL("mysql"),

    /**
     * Support Microsoft Sql Server 2017
     */
    SQL_SERVER("mssql"),

    VERTICA("vertica"),

    /**
     * Others
     */
    UNKNOWN("unknown");

    String source;

    SourceDialect(String source) {
        this.source = source;
    }

    public static SourceDialect getDialect(String name) {

        for (SourceDialect dialect : SourceDialect.values()) {
            if (dialect.source.equalsIgnoreCase(name)) {
                return dialect;
            }
        }
        return UNKNOWN;
    }
}

==> apache-kylin-4.0.4-source-release.zip: apache-kylin-4.0.4/core-common/src/main/java/org/apache/kylin/common/SourceDialect.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kylin.common;

/**
 * Decide sql pattern according to dialect from different data source
 */
public enum SourceDialect {
    HIVE("hive"),

    /**
     * Support MySQL 5.7
     */
    MYSQL("mysql"),

    /**
     * Support Microsoft Sql Server 2017 or above
     */
    MSSQL("mssql"),

    VERTICA("vertica"),

    POSTGRESQL("postgresql"),

    /**
     * Others
     */
    UNKNOWN("unknown");

    String source;

    SourceDialect(String source) {
        this.source = source;
    }

    public static SourceDialect getDialect(String name) {

        for (SourceDialect dialect : SourceDialect.values()) {
            if (dialect.source.equalsIgnoreCase(name)) {
                return dialect;
            }
        }
        return UNKNOWN;
    }
}
